#
# spec file for package mg
#
# Copyright (c) 2022-2023 Tomasz Hołubowicz <alternateved@pm.me>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

Name:           mg
Version:        3.7
Release:        1.4
Summary:        Micro GNU Emacs clone
License:        Unlicense
Group:          Productivity/Text/Editors
URL:            https://man.troglobit.com/man1/mg.1.html
Source:         https://github.com/troglobit/mg/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf automake
BuildRequires:  ncurses-devel

%description
Mg is micro GNU Emacs clone without lisp interpreter.

%prep
%setup -q

%build
autoreconf -i
%configure
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/
mv -f %{buildroot}%{_datadir}/doc/%{name}/ %{buildroot}%{_docdir}/%{name}/

rm %{buildroot}/usr/share/mg/tutorial.gz
rm %{buildroot}/usr/share/doc/packages/mg/.mg
rm %{buildroot}/usr/share/doc/packages/mg/UNLICENSE

%files
%license UNLICENSE
%doc README.md ChangeLog.md tutorial
%doc %{_docdir}/mg/
%{_bindir}/mg
%{_mandir}/man1/mg.1%{?ext_man}

%changelog
* Sun Aug 13 2023 Tomasz Hołubowicz <services@alternateved.com> - 3.7
- Update to version 3.7:
  * New command display-help-toggle, ensures the quick-help text is
  always shown in the status area, enabled by default
  * New command apply-macro-to-region-lines by Ben Scuron
  * New command end-or-call-last-kbd-macro, used in key bindings
  * Map function keys F1-F4 + F10 to common functions:
  F1: Toggle quick help
  F2: Save current buffer
  F3: Start keyboard macro
  F4: End keyboard macro, or call latest macro from mark
  * Sync with OpenBSD as of April 21, 2023:
  Add command set-tab-width to change per-buffer tab width
  Sync manual changes: grammar, visual improvements
  * Drop support for disabling no-tab-mode when calling configure
  script. Simplifies code greatly and not needed anymore since it is
  enabled by default upstream
  * Fix Home/End key for builds both with and without curses
  * Fix bug where the current markline is not reset after being
  cleared, by Ben Scuron
  * Sync with OpenBSD as of April 21, 2023:
  Fixes to no-tab-mode. OpenBSD had previously removed this mode,
  relevant change in this fork: indent next line with spaces
  Fix buffer overflow when no match is found for a search
* Mon Apr 10 2023 Tomasz Hołubowicz <services@alternateved.com> - 3.6
- Update to version 3.6:
  * Add support for exuberant/universal Ctags tags file format
  * Add support for M-, to pop-tag-mark, like GNU Emacs
  * Sync with mg upstream, OpenBSD 7.2, as of April 10 2023
  * Sync with mg upstream, OpenBSD 7.2, as of March 26 2023
  * Add support for --without-docs to skip installation of files to
    /usr/share/doc/mg, including the manual
  * Install gzipped tutorial in /usr/share/mg/, for built-in help
  * Fix #17: typos in *quick* help buffer, also replace duplicate undo with mark
    command instead
  * Fix #18: revert-buffer crash on macOS
* Tue May 31 2022 Tomasz Hołubowicz <alternateved@gmail.com>
- Use latest release instead of the package from GitHub generated link as only
  release comes with configure script
* Tue May 31 2022 Tomasz Hołubowicz <alternateved@gmail.com>
- Use proper tarball
* Tue May 31 2022 Tomasz Hołubowicz <alternateved@gmail.com>
- Apply suggestions from review:
  * absolute URL is required so the tarball could be verified against the
    upstream provided one
  * use commonly used form for manpage files
* Tue May 31 2022 Tomasz Hołubowicz <alternateved@gmail.com>
- Remove %%debug_package macro as mg-debuginfo already exists
* Mon May 30 2022 Tomasz Hołubowicz <alternateved@gmail.com>
- Initial version (3.5)
